frameTransform_displayTree {#master}
-----------------------

### Devices

#### frameTransformServer

* Added a new rpc command `generate_view` which generates via `dot (graphviz)` a pdf file, containing a diagram of the transforms tree





